@@ -45,7 +45,6 @@ import _exportable
 import _fileutil
 import _filtermanager
 import _mediadb
-import _metacmdmanager
 import _multilangmanager
 import _sequence
 import zmslog
@@ -57,7 +56,6 @@ Read system-configuration from $ZMS_HOME/etc/zms.conf
 class ConfDict:
 
     __confdict__ = None
-    __clazzes__ = {}
 
     @classmethod
     def get(cls):
@@ -75,12 +73,12 @@ class ConfDict:
         return cls.__confdict__
 
     @classmethod
-    def set_constructor(cls, key, clazz):
-      cls.__clazzes__[key] = clazz
-
-    @classmethod
-    def get_constructor(cls, key):
-      return cls.__clazzes__[key]
+    def forName(cls, name):
+      d = name.rfind(".")
+      clazzname = name[d+1:len(name)]
+      mod = __import__(name[0:d], globals(), locals(), [clazzname])
+      clazz = getattr(mod, clazzname)
+      return clazz
 
 
 """
@@ -115,7 +113,10 @@ def updateConf(self, REQUEST):
   createIfNotExists = False
   filenames = self.getConfFiles().keys()
   for filename in filenames:
-    self.importConf(filename,REQUEST,createIfNotExists)
+    try:
+      self.importConf(filename,REQUEST,createIfNotExists)
+    except:
+      pass
 
 
 ################################################################################
@@ -127,7 +128,6 @@ def updateConf(self, REQUEST):
 ################################################################################
 class ConfManager(
     _multilangmanager.MultiLanguageManager,
-    _metacmdmanager.MetacmdManager,
     _filtermanager.FilterManager,
     ):
     zope.interface.implements(
@@ -146,7 +146,6 @@ class ConfManager(
     addZMSSqlDbForm = PageTemplateFile('addzmssqldbform',globals()) 
     manage_customize = PageTemplateFile('zpt/ZMS/manage_customize',globals())
     manage_customizeLanguagesForm = PageTemplateFile('zpt/ZMS/manage_customizelanguagesform',globals())
-    manage_customizeMetacmdForm = PageTemplateFile('zpt/metacmd/manage_customizeform',globals()) 
     manage_customizeFilterForm = PageTemplateFile('zpt/ZMS/manage_customizefilterform',globals())
     manage_customizeDesignForm = PageTemplateFile('zpt/ZMS/manage_customizedesignform',globals())
 
@@ -193,11 +192,11 @@ class ConfManager(
       elif filename.find('.filter.') > 0:
         _filtermanager.importXml(self, xmlfile, REQUEST, createIfNotExists)
       elif filename.find('.metadict.') > 0:
-        self.metaobj_manager.importMetadictXml(xmlfile, REQUEST, createIfNotExists)
+        self.getMetaobjManager().importMetadictXml(xmlfile, REQUEST, createIfNotExists)
       elif filename.find('.metaobj.') > 0:
-        self.metaobj_manager.importMetaobjXml(xmlfile, REQUEST, createIfNotExists)
+        self.getMetaobjManager().importMetaobjXml(xmlfile, REQUEST, createIfNotExists)
       elif filename.find('.metacmd.') > 0:
-        _metacmdmanager.importXml(self, xmlfile, REQUEST, createIfNotExists)
+        self.getMetacmdManager().importXml(xmlfile, REQUEST, createIfNotExists)
       elif filename.find('.langdict.') > 0:
         _multilangmanager.importXml(self, xmlfile, REQUEST, createIfNotExists)
       elif filename.find('.textfmt.') > 0:
@@ -210,7 +209,7 @@ class ConfManager(
     # --------------------------------------------------------------------------
     #  Returns configuration-files from $ZMS_HOME/import-Folder
     # --------------------------------------------------------------------------
-    security.declareProtected('View', 'ZMS Administrator')
+    security.declareProtected('ZMS Administrator', 'getConfFiles')
     def getConfFiles(self, pattern=None, REQUEST=None, RESPONSE=None):
       """
       ConfManager.getConfFiles
@@ -398,7 +397,6 @@ class ConfManager(
         if IZMSConfigurationProvider in list(zope.interface.providedBy(ob)):
           for d in ob.manage_sub_options():
             l.append(self.operator_setitem(d.copy(),'action',ob.id+'/'+d['action']))
-      l.append({'label':'TAB_METACMD','action':'manage_customizeMetacmdForm'})
       l.append({'label':'TAB_FILTER','action':'manage_customizeFilterForm'})
       l.append({'label':'TAB_DESIGN','action':'manage_customizeDesignForm'})
       return l
@@ -657,8 +655,8 @@ class ConfManager(
             obj = zmslog.ZMSLog()
             self._setObject(obj.id, obj)
             message = 'Added '+meta_type
-          elif meta_type in ['ZMSWorkflowProvider','ZMSWorkflowProviderAcquired']:
-            obj = ConfDict.get_constructor(meta_type)()
+          else:
+            obj = ConfDict.forName(meta_type+'.'+meta_type)()
             self._setObject(obj.id, obj)
             message = 'Added '+meta_type
         elif btn == 'Remove':
@@ -824,7 +822,19 @@ class ConfManager(
     ############################################################################
 
     def getMetaobjManager(self):
-      return self.metaobj_manager
+      metaobj_manager = getattr(self,'metaobj_manager',None)
+      if metaobj_manager is None:
+        class DefaultMetaobjManager:
+          def getMetaobjId(self, name): return None
+          def getMetaobjIds(self, sort=1, excl_ids=[]): return []
+          def getMetaobj(self, id): return None
+          def getMetaobjAttrIds(self, meta_id, types=[]): return []
+          def getMetaobjAttrs(self, meta_id,  types=[]): return []
+          def getMetaobjAttr(self, id, attr_id, syncTypes=['resource']): return None
+          def getMetaobjAttrIdentifierId(self, meta_id): return None
+          def notifyMetaobjAttrAboutValue(self, meta_id, key, value): return None
+        metaobj_manager = DefaultMetaobjManager()
+      return metaobj_manager
 
     def getMetaobjId(self, name):
       return self.getMetaobjManager().getMetaobjId( name)
@@ -851,6 +861,37 @@ class ConfManager(
       return self.getMetaobjManager().notifyMetaobjAttrAboutValue( meta_id, key, value)
 
 
+    ############################################################################
+    ###
+    ###   Interface IZMSMetacmdProvider: delegate
+    ###
+    ############################################################################
+
+    def getMetacmdManager(self):
+      metacmd_manager = getattr(self,'metacmd_manager',None)
+      if metacmd_manager is None:
+        class DefaultManager:
+          def getMetaCmdDescription(self, id=None, name=None): return None
+          def getMetaCmd(self, id=None, name=None): return None
+          def getMetaCmdIds(self, sort=1): return []
+          def getMetaCmds(self, sort=True): return []
+        metacmd_manager = DefaultManager()
+      return metacmd_manager
+
+    def getMetaCmdDescription(self, id=None, name=None):
+       """ getMetaCmdDescription """
+       return self.getMetacmdManager().getMetaCmdDescription(id,name)
+
+    def getMetaCmd(self, id=None, name=None):
+       return self.getMetacmdManager().getMetaCmd(id,name)
+
+    def getMetaCmdIds(self, sort=1):
+       return self.getMetacmdManager().getMetaCmdIds(sort)
+
+    def getMetaCmds(self, sort=True):
+      return self.getMetacmdManager().getMetaCmds(sort)
+
+
     ############################################################################
     ###
     ###   Interface IZMSFormatProvider: delegate
