@@ -154,9 +154,7 @@ def setProcess(self, newId, newAcquired=0, newName='', newType='process', newCom
       newCommand += 'RESPONSE =  request.RESPONSE\n'
       newCommand += '\n'
       newCommand += '# Return a string identifying this script.\n'
-      newCommand += 'print "This is the", script.meta_type, \'"%s"\' % script.getId(),\n'
-      newCommand += 'if script.title:\n'
-      newCommand += '    print "(%s)" % html_quote(script.title),\n'
+      newCommand += 'print "This is the Python Script %s" % script.getId()\n'
       newCommand += 'print "in", container.absolute_url()\n'
       newCommand += 'return printed\n'
       newCommand += '\n'
