@@ -442,7 +442,12 @@ class ZReferableItem:
   def getLinkObj(self, url, REQUEST={}):
     ob = None
     if isInternalLink(url):
-      if not url.startswith('{$__'):
+      # Extension Point
+      ep = self.getConfProperty('ZReferableItem.getLinkObj','')
+      if ep != '':
+        ob = self.evalMetaobjAttr(ep,url=url)
+      # Default
+      elif not url.startswith('{$__'):
         docElmnt = None
         path = url[2:-1]
         i = path.find('#')
@@ -490,7 +495,7 @@ class ZReferableItem:
         index_html = './index_%s.html?op=not_found&url=%s'%(REQUEST.get('lang',self.getPrimaryLanguage()),url)
       else:
         index_html = ob.getObjProperty('getHref2IndexHtml',REQUEST)
-        if index_html == '':
+        if not index_html:
           index_html = ob.getHref2IndexHtml(REQUEST)
       return index_html + ref_anchor
     elif isMailLink (url): 
