@@ -33,6 +33,15 @@ $(function(){
 			}
 		});
 
+	// Main Menu Toggle
+	$('.zmi .main-nav li.active a').click(function(event) {
+		if ( $(window).width() < 767) {
+			event.preventDefault();
+			$('.zmi .main-nav li:not(.active)').toggle();
+			return false;
+		}
+	});
+
 	// Textarea:
 	// single-line
 	$('div.single-line').each(function() {
@@ -766,6 +775,7 @@ ZMIActionList.prototype.over = function(el, evt, e) {
 	params['context_id'] = context_id;
 	// JQuery.AJAX.get
 	$.get( action, params, function(data) {
+		$ZMI.writeDebug("[ZMIActionList.over]: data="+data);
 		// Reset wait-cursor.
 		$(document.body).css( "cursor", "auto");
 		// Exit.
@@ -777,8 +787,12 @@ ZMIActionList.prototype.over = function(el, evt, e) {
 		var actions = value['actions'];
 		$(el).append('<ul class="dropdown-menu"></ul>');
 		$ul = $("ul.dropdown-menu",el);
+		$ZMI.writeDebug("[ZMIActionList.over]: "+actions[1][0]);
 		var startsWithSubmenu = actions.length > 1 && actions[1][0].indexOf("-----") == 0 && actions[1][0].lastIndexOf("-----") > 0;
+		$ZMI.writeDebug("[ZMIActionList.over]: startsWithSubmenu="+startsWithSubmenu);
+		var o = 1;
 		if (startsWithSubmenu) {
+			var o = 2;
 			var html = '';
 			var opticon = '';
 			if (actions[1].length > 2) {
@@ -810,7 +824,7 @@ ZMIActionList.prototype.over = function(el, evt, e) {
 			//
 			$ul.append('<li><a href="javascript:zmiToggleSelectionButtonClick($(\'li.zmi-item' + (id==''?':first':'#zmi_item_'+id) + '\'))">'+$ZMI.icon("icon-check")+' '+getZMILangStr('BTN_SLCTALL')+'/'+getZMILangStr('BTN_SLCTNONE')+'</a></li>');
 		}
-		for (var i = 2; i < actions.length; i++) {
+		for (var i = o; i < actions.length; i++) {
 			var optlabel = actions[i][0];
 			var optvalue = actions[i][1];
 			if (optlabel.indexOf("-----") == 0 && optlabel.lastIndexOf("-----") > 0) {
@@ -1074,8 +1088,15 @@ function zmiBrowseObjs(fmName, elName, lang) {
 	return false;
 }
 
-function zmiBrowseObjsApplyUrlValue(fmName, elName, elValue) {
+function zmiBrowseObjsApplyUrlValue(fmName, elName, elValue, elTitle) {
 	$('form[name='+fmName+'] input[name='+elName+']').val(elValue);
+	if (typeof elTitle != "undefined") {
+		$('form[name='+fmName+'] input[name^=title]').each(function() {
+				if ($(this).val()=='') {
+					$(this).val(elTitle);
+				} 
+			});
+	}
 }
 
 function zmiDialogClose() {
