@@ -41,11 +41,12 @@ import _objattrs
 import _xmllib
 import _zcatalogmanager
 import _zmsattributecontainer
-import ZMSMetamodelProvider, ZMSFormatProvider, ZMSWorkflowProvider, ZMSWorkflowProviderAcquired
+import ZMSMetamodelProvider, ZMSMetacmdProvider, ZMSFormatProvider, ZMSWorkflowProvider, ZMSWorkflowProviderAcquired
 from zmscustom import ZMSCustom
 from zmslinkcontainer import ZMSLinkContainer
 from zmslinkelement import ZMSLinkElement
 from zmslog import ZMSLog
+from zmsobject import ZMSObject
 from zmssqldb import ZMSSqlDb
 from zmstrashcan import ZMSTrashcan
 
@@ -53,33 +54,48 @@ __all__= ['ZMS']
 
 
 ################################################################################
-################################################################################
-###
-###  Common Function(s)
-###
-################################################################################
-################################################################################
-
-# ------------------------------------------------------------------------------
-#  ZMS.recurse_cleanArtefacts:
 #
-#  Clean artefacts.
-# ------------------------------------------------------------------------------
-def recurse_cleanArtefacts( self, level=0):
-  from OFS.CopySupport import absattr
-  # Recursion.
-  last_id = None
-  for ob in self.objectValues():
-    if absattr(self.id) == absattr(ob.id):
-      print (" "*level)+"recurse_cleanArtefacts", ob.absolute_url(), ob.meta_type
-      raise zExceptions.InternalError('InfiniteRecursionError')
-    else:
-      try:
-        recurse_cleanArtefacts( ob, level+1)
-      except "InfiniteRecursionError":
-        print (" "*level)+"recurse_cleanArtefacts: clean artefact ", ob.absolute_url(), ob.meta_type
-        self._delObject(absattr(ob.id), suppress_events=True)
+# ZMS Object Index
+#
+################################################################################
 
+import zope.event
+try:
+# module path of a pip based installation
+  from zope.container.contained import ObjectAddedEvent
+  from zope.container.contained import ObjectMovedEvent
+  from zope.container.contained import ObjectRemovedEvent
+except:
+# module path of an egg based installation
+  from zope.app.container.contained import ObjectAddedEvent
+  from zope.app.container.contained import ObjectMovedEvent
+  from zope.app.container.contained import ObjectRemovedEvent
+
+def subscriber(event):
+  if isinstance(event,ObjectAddedEvent):
+    if isinstance(event.object,ZMSObject):
+      print "ZMS: add", event.object, event.newParent, event.newName
+      if isinstance(event.newParent,ZMSObject):
+        _globals.triggerEvent(event.object,"ObjectAdded")
+  elif isinstance(event,ObjectMovedEvent):
+    if isinstance(event.object,ZMSObject):
+      print "ZMS: move", event.object, event.newParent, event.newName
+      if isinstance(event.newParent,ZMSObject):
+        _globals.triggerEvent(event.object,"ObjectMoved")
+      elif event.newParent is None:
+        _globals.triggerEvent(event.object,"ObjectRemoved")
+  elif isinstance(event,ObjectRemovedEvent):
+    if isinstance(event.object,ZMSObject):
+      print "ZMS: remove", event.object
+      _globals.triggerEvent(event.object,"ObjectRemoved")
+zope.event.subscribers.append(subscriber)
+
+
+################################################################################
+#
+# Common Function(s)
+#
+################################################################################
 
 # ------------------------------------------------------------------------------
 #  ZMS.recurse_updateVersionBuild:
@@ -140,6 +156,14 @@ def recurse_updateVersionBuild(docElmnt, self, REQUEST):
     if not self.getAutocommit() and self.isVersionContainer():
       self.syncObjModifiedChildren( REQUEST)
   
+  ##### Build 135: Metacmd-Provider ####
+  if getattr( docElmnt, 'build', '000') < '135':
+      commands = self.getConfProperty('ZMS.custom.commands',[])
+      if len(commands)>0:
+        manager = ZMSMetacmdProvider.ZMSMetacmdProvider(commands)
+        self._setObject( manager.id, manager)
+        self.delConfProperty('ZMS.custom.commands')
+
   # Recursion.
   for ob in self.objectValues( self.dGlobalAttrs.keys()):
     recurse_updateVersionBuild(docElmnt, ob, REQUEST)
@@ -248,10 +272,7 @@ def initZMS(self, id, titlealt, title, lang, manage_lang, REQUEST):
   obj.recreateCatalog(lang)
   
   ### Init ZMS object-model.
-  conf = 'zms'
-  if REQUEST.get('initialization',0) == 3:
-    conf = 'zms2go'
-  _confmanager.initConf(obj, conf, REQUEST)
+  _confmanager.initConf(obj, 'zms', REQUEST)
   
   ### Init default-configuration.
   _confmanager.initConf(obj, 'default', REQUEST)
@@ -281,11 +302,9 @@ def initContent(self, filename, REQUEST):
 
 
 ################################################################################
-################################################################################
-###   
-###   Constructor
-###   
-################################################################################
+#
+# Constructor
+#
 ################################################################################
 manage_addZMSForm = PageTemplateFile('manage_addzmsform', globals())
 def manage_addZMS(self, lang, manage_lang, REQUEST, RESPONSE):
@@ -306,7 +325,7 @@ def manage_addZMS(self, lang, manage_lang, REQUEST, RESPONSE):
     
     ##### Add ZMS ####
     titlealt = 'ZMS home'
-    title = 'ZMS - ZOPE-based contentmanagement system for science, technology and medicine'
+    title = 'ZMS - Python-based Content Management System for Science, Technology and Medicine'
     obj = initZMS(homeElmnt,'content',titlealt,title,lang,manage_lang,REQUEST)
     
     ##### Default content ####
@@ -315,25 +334,6 @@ def manage_addZMS(self, lang, manage_lang, REQUEST, RESPONSE):
     elif REQUEST.get('initialization',0)==3:
       initContent(obj,'zms2go.default.zip',REQUEST)
     
-    ##### E-Learning components ####
-    if REQUEST.get('initialization',0)==2:
-      # Create Home.
-      lcmsHomeElmnt = initTheme(homeElmnt,'lcms.zexp','lcms',REQUEST)
-      # Create LCMS.
-      titlealt = 'LCMS'
-      title = 'Learning Content Management System'
-      lcms = initZMS(lcmsHomeElmnt,'content',titlealt,title,lang,manage_lang,REQUEST)
-      lcms.setLanguage('eng', 'English', 'ger', 'eng')
-      # Init configuration.
-      _confmanager.initConf(lcms, 'lcms', REQUEST)
-      _confmanager.initConf(obj, 'lms', REQUEST)
-      # Register Portal/Client.
-      lcms.setConfProperty('Portal.Master',homeElmnt.id)
-      obj.setConfProperty('Portal.Clients',[lcmsHomeElmnt.id])
-      # Init content.
-      initContent(lcms,'lcms.default.xml',REQUEST)
-      initContent(obj,'lms.default.zip',REQUEST)
-    
     ##### Configuration ####
     
     #-- QUnit
@@ -391,11 +391,9 @@ def containerFilter(container):
 
 
 ################################################################################
-################################################################################
-###
-###  Class
-###
-################################################################################
+#
+#  Class
+#
 ################################################################################
 class ZMS(
         ZMSCustom,
@@ -408,7 +406,7 @@ class ZMS(
 
     # Version-Info.
     # -------------
-    zms_build = '134'        # Internal use only, designates object model!
+    zms_build = '135'        # Internal use only, designates object model!
     zms_patch = 'c'          # Internal use only!
 
     # Properties.
@@ -441,7 +439,6 @@ class ZMS(
     __administratorPermissions__ = (
         'manage_customize', 'manage_customizeSystem',
         'manage_changeLanguages', 'manage_customizeLanguagesForm',
-        'manage_changeMetacmds', 'manage_customizeMetacmdForm',
         'manage_customizeDesign', 'manage_customizeDesignForm',
         )
     __authorPermissions__ = (
@@ -670,17 +667,6 @@ class ZMS(
         setattr( self, 'patch', self.zms_patch)
         transaction.commit()
         message += 'Synchronized object-model from patch #%s%s to #%s%s!<br/>'%(build,patch,self.zms_build,self.zms_patch)
-      if maintenance:
-        try:
-          self.getTrashcan().run_garbage_collection()
-        except:
-          _globals.writeError( self, '[updateVersion]: can\'t run garbage collection')
-      
-      # Process clients.
-      if message:
-        for portalClient in self.getPortalClients():
-          message += portalClient.updateVersion( lang, REQUEST, False)
-      
       return message
 
 
