@@ -397,6 +397,45 @@ class ZMSCustom(ZMSContainerObject):
       return export
 
 
+    # --------------------------------------------------------------------------
+    #  ZMSCustom.getEntityRecordHandler
+    # --------------------------------------------------------------------------
+    def getEntityRecordHandler(self, id):
+      class EntityRecordHandler:
+        def __init__(self, parent, id):
+          self.parent = parent 
+          self.id = id
+          self.fk = {}
+          metaObjIds = parent.getMetaobjIds()
+          for k in parent.getMetaobjAttrIds(id):
+            metaObjAttr = parent.getMetaobjAttr(id,k)
+            if metaObjAttr['type'] in metaObjIds:
+              fkMetaObj = parent.getMetaobj(metaObjAttr['type'])
+              fkMetaObjIdId = fkMetaObj['attrs'][0]['id']
+              for fkContainer in parent.getParentNode().getChildNodes(self.parent.REQUEST,metaObjAttr['type']):
+                fkMetaObj = parent.getMetaobj(fkContainer.meta_id);
+                fkMetaObjAttrIdRecordSet = fkMetaObj['attrs'][0]['id'];
+                fkMetaObjRecordSet = fkContainer.attr(fkMetaObjAttrIdRecordSet);
+                fkMetaObjIdId = parent.getMetaobjAttrIdentifierId(fkContainer.meta_id)
+                self.fk[k] = {'fkMetaObj':fkMetaObj,'fkMetaObjRecordSet':fkMetaObjRecordSet,'fkMetaObjIdId':fkMetaObjIdId}
+        __call____roles__ = None
+        def __call__(self, r):
+          d = {}
+          for k in r.keys():
+            v = r[k]
+            if k in self.fk.keys():
+              fk = self.fk[k]
+              fkMetaObj = fk['fkMetaObj']
+              fkMetaObjRecordSet = fk['fkMetaObjRecordSet']
+              fkMetaObjIdId = fk['fkMetaObjIdId']
+              for fkMetaObjRecord in filter(lambda x:x.get(fkMetaObjIdId)==v,fkMetaObjRecordSet):
+                fkMetaObjAttrs = filter(lambda x:x['type']=='string' and fkMetaObjRecord.get(x['id'],'')!='',fkMetaObj['attrs'])
+                v = ', '.join(map(lambda x:str(fkMetaObjRecord.get(x['id'])),fkMetaObjAttrs))
+            d[k] =  v
+          return d
+      return EntityRecordHandler(self,id)
+
+
     ############################################################################
     #  ZMSCustom.manage_changeRecordSet:
     #
@@ -414,6 +453,7 @@ class ZMSCustom(ZMSContainerObject):
           self.setObjStateModified(REQUEST)
           
           metaObj = self.getMetaobj(self.meta_id)
+          metaObjAttrIds = self.getMetaobjAttrIds(self.meta_id)
           res_abs = self.recordSet_Init(REQUEST)
           if action == 'insert':
             row = {}
@@ -472,12 +512,13 @@ class ZMSCustom(ZMSContainerObject):
                 row['sort_id'] = new_sort_id
               else:
                 row['sort_id'] = row['sort_id']*10
-            # Normalize sort-ids.
+            message = self.getZMILangStr('MSG_MOVEDOBJTOPOS')%('%s %i'%(self.getZMILangStr('ATTR_RECORD'),pos),newpos)
+          # Normalize sort-ids.
+          if 'sort_id' in metaObjAttrIds:
             res_abs = self.sort_list(res_abs,'sort_id')
             for i in range(len(res_abs)):
               row = res_abs[i]
               row['sort_id'] = i+1
-            message = self.getZMILangStr('MSG_MOVEDOBJTOPOS')%('%s %i'%(self.getZMILangStr('ATTR_RECORD'),pos),newpos)
           self.setObjProperty(metaObj['attrs'][0]['id'],res_abs,lang)
           
           ##### VersionManager ####
